package com.ruoyi.project.production.mapper;

import java.util.List;

import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TMonthplan;

/**
 * 生产计划及月报Mapper接口
 *
 * @author ruoyi
 * @date 2020-11-26
 */
public interface TMonthplanMapper
{
    /**
     * 查询生产计划及月报
     *
     * @param id 生产计划及月报ID
     * @return 生产计划及月报
     */
    public TMonthplan selectTMonthplanById(Long id);

    /**
     * 查询生产计划及月报列表
     *
     * @param tMonthplan 生产计划及月报
     * @return 生产计划及月报集合
     */
    @DataScope(deptAlias = "d")
    public List<TMonthplan> selectTMonthplanList(TMonthplan tMonthplan);

    /**
     * 新增生产计划及月报
     *
     * @param tMonthplan 生产计划及月报
     * @return 结果
     */
    public int insertTMonthplan(TMonthplan tMonthplan);

    /**
     * 修改生产计划及月报
     *
     * @param tMonthplan 生产计划及月报
     * @return 结果
     */
    public int updateTMonthplan(TMonthplan tMonthplan);

    /**
     * 删除生产计划及月报
     *
     * @param id 生产计划及月报ID
     * @return 结果
     */
    public int deleteTMonthplanById(Long id);

    /**
     * 批量删除生产计划及月报
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTMonthplanByIds(Long[] ids);
}
